/**
 * Copyright (C) 2003-2004 Funambol
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package sync4j.exchange.items.calendar.manager;

import java.io.IOException;

import sync4j.exchange.items.calendar.dao.CalendarDAO;
import sync4j.exchange.items.calendar.model.Calendar;
import sync4j.exchange.DataAccessException;

/*
 * This class defines methods to access calendars data
 * in exchange server datastore
 *
 * @author Fabio Maggi @ Funambol
 * @version $Id: CalendarManager.java,v 1.3 2004/08/04 17:01:45 fabius Exp $
 *
 **/
public class CalendarManager {

    //------------------------------------------------------------- Constants

    //------------------------------------------------------------- Private Data

    CalendarDAO cd = null ;

    //------------------------------------------------------------- Costructor

    public CalendarManager(String exchangeServerHost ,
                           int    exchangeServerPort)
        throws DataAccessException {

        this.cd = new CalendarDAO (exchangeServerHost ,
                                   exchangeServerPort);

    }

    //------------------------------------------------------------- Public methods

    /**
     * get all calendars
     *
     * @param username
     * @param credentials
     * @param sourceURI
     *
     * @return array of find calendars
     *
     * @throws sync4j.exchange.util.DataAccessException
     **/
    public Calendar[] getAllCalendars(String   username    ,
                                      String   credentials ,
                                      String   sourceURI   )
        throws DataAccessException {

        return this.cd.getCalendars(username      ,
                                    credentials   ,
                                    new String[0] ,
                                    sourceURI     );
    }

    /**
     * get calendars
     *
     * @param username
     * @param credentials
     * @param ids
     * @param sourceURI
     *
     * @return array of find calendars
     *
     * @throws sync4j.exchange.util.DataAccessException
     **/
    public Calendar[] getCalendars(String   username    ,
                                   String   credentials ,
                                   String[] ids         ,
                                   String   sourceURI   )
        throws DataAccessException {

         return this.cd.getCalendars(username    ,
                                     credentials ,
                                     ids         ,
                                     sourceURI   );

    }

    /**
     * get calendar by key
     *
     * @param id
     * @param username
     * @param credentials
     *
     * @return find calendar
     *
     * @throws sync4j.exchange.util.DataAccessException
     **/
    public Calendar getCalendarById(String username    ,
                                    String credentials ,
                                    String id          ,
                                    String sourceURI   )
        throws DataAccessException {

        Calendar[] calendars = null;

        calendars = this.cd.getCalendars(username          ,
                                         credentials       ,
                                         new String[] {id} ,
                                         sourceURI);

        if (calendars == null || !(calendars.length > 0)) {
            return null;
        }

        return calendars[0];

    }

    /**
     * add calendar
     *
     * @param calendar
     * @param username
     * @param credentials
     * @param sourceURI
     *
     * @return new calendar
     *
     * @throws sync4j.exchange.util.DataAccessException
     **/
    public Calendar setCalendar(Calendar calendar    ,
                                String   username    ,
                                String   credentials ,
                                String   sourceURI
                              )
        throws DataAccessException {

        return this.cd.setCalendar(calendar    ,
                                   username    ,
                                   credentials ,
                                   sourceURI   );

    }

    /**
     * remove calendar
     *
     * @param calendar
     * @param username
     * @param principal
     * @param sourceURI
     *
     * @throws sync4j.exchange.util.DataAccessException
     **/
    public void removeCalendar(Calendar calendar  ,
                               String   username  ,
                               String   principal ,
                               String   sourceURI )
        throws DataAccessException {

        this.cd.removeCalendar(calendar, username, principal, sourceURI);

    }

}